@@ -7,13 +7,13 @@ from w3bsite.classes import utils, views
 from w3bsite.classes import defaults as _defaults_
 
 # the authentication requests.
-class Requests(_defaults_.dev0s.defaults.):
+class Requests(_defaults_.Defaults):
 	def __init__(self, 
 		# passed Website.x objects.
 		defaults=None,
 	):
 		# defaults.
-		_defaults_.dev0s.defaults.__init__(self)
+		_defaults_.Defaults.__init__(self)
 		self.assign(defaults.dict())
 
 		# urlpatterns.
